==> haskell-case-insensitive-1.2.0.6-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-case-insensitive.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: case-insensitive
version: 1.2.0.6
id: case-insensitive-1.2.0.6-I0Jt0nwhqya3cOqVnbSTZ9
key: case-insensitive-1.2.0.6-I0Jt0nwhqya3cOqVnbSTZ9
license: BSD3
copyright: 2011 Bas van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/case-insensitive
synopsis: Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.
category: Data, Text
author: Bas van Dijk
exposed: True
exposed-modules:
    Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules: Data.CaseInsensitive.Internal
abi: c440b5b85fc04b1ce80708f610f192b7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/case-insensitive-1.2.0.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/case-insensitive-1.2.0.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/case-insensitive-1.2.0.6
hs-libraries: HScase-insensitive-1.2.0.6-I0Jt0nwhqya3cOqVnbSTZ9
depends:
    base-4.9.0.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock
haddock-html: /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-case-insensitive-1.2.0.7-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-case-insensitive.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: case-insensitive
version: 1.2.0.7
id: case-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz
key: case-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz
license: BSD3
copyright: 2011 Bas van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/case-insensitive
synopsis: Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.
category: Data, Text
author: Bas van Dijk
exposed: True
exposed-modules:
    Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules: Data.CaseInsensitive.Internal
abi: 3192e9625856825201eef0d072814261
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/case-insensitive-1.2.0.7
library-dirs: /usr/lib/ghc-8.0.1/site-local/case-insensitive-1.2.0.7
data-dir: /usr/share/arm-linux-ghc-8.0.1/case-insensitive-1.2.0.7
hs-libraries: HScase-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz
depends:
    base-4.9.0.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock
haddock-html: /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
